@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 
-# $Id: simple.pl,v 1.7 2004/11/23 17:06:27 mike Exp $
+# $Id: simple.pl,v 1.11 2004/12/01 17:34:07 mike Exp $
 
 use strict;
 use warnings;
@@ -9,11 +9,13 @@ use Net::Z3950::RadioMARC;
 
 
 set host => 'indexdata.com', port => '210', db => 'gils';
+#set host => 'localhost', port => '9999', db => 'Default';
 set delay => 3;
 set verbosity => 2;
 set messages => { ok => "This is the default 'OK' message" };
 
 add "etc/sample.marc";
+set identityField => '710$a';
 
 test '@attr 1=4 data', { ok => '245$a is searchable as 1=4',
 			 notfound => 'Search OK but record not found',
